==> haskell-rio-orphans-0.1.1.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-orphans
version: 0.1.1.0
id: rio-orphans-0.1.1.0-FvsggZqQMCv4R0lDICAxkU
key: rio-orphans-0.1.1.0-FvsggZqQMCv4R0lDICAxkU
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>
category: Control
abi: 245bdfb00c5cb47b2dac36f0f2f9bb5f
exposed: True
exposed-modules:
    RIO.Orphans
hidden-modules: Paths_rio_orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-orphans-0.1.1.0
hs-libraries: HSrio-orphans-0.1.1.0-FvsggZqQMCv4R0lDICAxkU
depends:
    base-4.12.0.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-2.4.17-EIkTgShDAYOFSHXqB4KinN
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-logger-0.3.30-2kmzjTpC8MSG6LltA7aDUf
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
haddock-interfaces: /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html: /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-orphans-0.1.1.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-rio-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: rio-orphans
version: 0.1.1.0
id: rio-orphans-0.1.1.0-6XzAsSbhw18Izs7D7sxy5d
key: rio-orphans-0.1.1.0-6XzAsSbhw18Izs7D7sxy5d
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/rio#readme
synopsis: Orphan instances for the RIO type in the rio package
description:
    See README and Haddocks at <https://www.stackage.org/package/rio-orphans>
category: Control
abi: 56b5944a7ef34ab50ff24ca80c557a96
exposed: True
exposed-modules:
    RIO.Orphans
hidden-modules: Paths_rio_orphans
import-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/rio-orphans-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/rio-orphans-0.1.1.0
hs-libraries: HSrio-orphans-0.1.1.0-6XzAsSbhw18Izs7D7sxy5d
depends:
    base-4.12.0.0 exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-2.4.17-Cd6ZUQsGKTSHW7YusNSTv8
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-logger-0.3.30-BBOvFsZkZCA5ie1Efxjd0q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
haddock-interfaces: /usr/share/doc/haskell-rio-orphans/html/rio-orphans.haddock
haddock-html: /usr/share/doc/haskell-rio-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
